@@ -19,16 +19,23 @@ class clientsocket : public client {
 		clientsocket	&operator=(const clientsocket &c);
 		virtual		~clientsocket();
 
-#ifdef FIONBIO
+		virtual bool	supportsBlockingNonBlockingModes();
+				// Returns false if the system doesn't support
+				// blocking/nonblocking modes and true
+				// otherwise.
+
 		virtual bool	useNonBlockingMode() const;
 				// Puts the file descriptor in non-blocking
 				// mode.  Returns true on success and false on
 				// failure.
+				// Returns false if the system doesn't support
+				// blocking/nonblocking modes.
 		virtual bool	useBlockingMode() const;
 				// Puts the file descriptor in blocking mode.
 				// Returns true on success and false on
 				// failure.
-#endif
+				// Returns false if the system doesn't support
+				// blocking/nonblocking modes.
 
 	#include <rudiments/private/clientsocket.h>
 };
