@@ -18,9 +18,9 @@ class mutex {
 	public:
 			mutex();
 			// Initialize a mutex.
-			#if defined(HAVE_PTHREAD_MUTEX_T)
+			#if defined(RUDIMENTS_HAVE_PTHREAD_MUTEX_T)
 			mutex(pthread_mutex_t *mut);
-			#elif defined(HAVE_CREATE_MUTEX)
+			#elif defined(RUDIMENTS_HAVE_CREATE_MUTEX)
 			mutex(HANDLE mut);
 			#endif
 			// Attach already initialized "mut" to this instance.
@@ -39,9 +39,9 @@ class mutex {
 			// Unlock the mutex.
 			// Returns true on success and false if an error occurs.
 
-		#if defined(HAVE_PTHREAD_MUTEX_T)
+		#if defined(RUDIMENTS_HAVE_PTHREAD_MUTEX_T)
 		pthread_mutex_t	*getMutex();
-		#elif defined(HAVE_CREATE_MUTEX)
+		#elif defined(RUDIMENTS_HAVE_CREATE_MUTEX)
 		HANDLE		getMutex();
 		#endif
 				// Returns the mutex used by
