@@ -2,8 +2,7 @@
 // See the COPYING file for more information.
 
 	private:
-		int	argc;
-		char	**argv;
-
 		commandline(const commandline &c);
 		commandline	&operator=(const commandline &c);
+
+		commandlineprivate	*pvt;
