@@ -12,7 +12,3 @@
 		int64_t		fpathConf(int name);
 
 		directoryprivate	*pvt;
-
-		#ifdef HAVE_READDIR_R
-		int64_t	bufferSize(DIR *dirp);
-		#endif
