@@ -2,7 +2,4 @@
 // See the COPYING file for more information.
 
 #include <rudiments/dictionary.h>
-
-#ifdef RUDIMENTS_HAS_THREADS
-	#include <rudiments/mutex.h>
-#endif
+#include <rudiments/mutex.h>
