@@ -3,8 +3,6 @@
 
 #include <rudiments/private/inttypes.h>
 
-#ifdef RUDIMENTS_HAS_THREADS
-	#include <rudiments/mutex.h>
-#endif
-
 #include <netdb.h>
+
+#include <rudiments/mutex.h>
