@@ -3,6 +3,6 @@
 
 #include <rudiments/private/inttypes.h>
 
-#include <netdb.h>
+// for sockaddr_in
 #include <sys/types.h>
 #include <netinet/in.h>
