@@ -3,5 +3,10 @@
 
 #include <rudiments/private/inttypes.h>
 
+// for struct timespec
+#include <rudiments/private/snoozeincludes.h>
+
 #include <sys/types.h>
+
+// for struct sembuf
 #include <sys/sem.h>
