@@ -3,9 +3,4 @@
 
 #include <rudiments/private/inttypes.h>
 
-#ifdef RUDIMENTS_HAS_THREADS
-	#include <rudiments/mutex.h>
-#endif
-
-#include <netdb.h>
-#include <netinet/in.h>
+#include <rudiments/mutex.h>
