@@ -3,9 +3,7 @@
 
 #include <rudiments/private/inttypes.h>
 
+// for uid_t
 #include <sys/types.h>
-#include <shadow.h>
 
-#ifdef RUDIMENTS_HAS_THREADS
-	#include <rudiments/mutex.h>
-#endif
+#include <rudiments/mutex.h>
