@@ -1,7 +1,8 @@
 // Copyright (c) 2002 David Muse
 // See the COPYING file for more information.
 
-	private:
+	friend class xmldomnode;
+	protected:
 			void	reset();
 
 			bool	tagStart(const char *name);
@@ -15,4 +16,7 @@
 				xmldom(const xmldom &x);
 			xmldom	&operator=(const xmldom &x);
 
+			const char	*cacheString(const char *string);
+			void		unCacheString(const char *string);
+
 			xmldomprivate	*pvt;
