@@ -19,16 +19,23 @@ class serversocket : public server {
 		serversocket	&operator=(const serversocket &s);
 		virtual		~serversocket();
 
-#ifdef FIONBIO
+		virtual bool	supportsBlockingNonBlockingModes();
+				// Returns false if the system doesn't support
+				// blocking/nonblocking modes and true
+				// otherwise.
+
 		virtual bool	useNonBlockingMode() const;
 				// Puts the file descriptor in non-blocking
 				// mode.  Returns true on success and false on
 				// failure.
+				// Returns false if the system doesn't support
+				// blocking/nonblocking modes.
 		virtual bool	useBlockingMode() const;
 				// Puts the file descriptor in blocking mode.
 				// Returns true on success and false on
 				// failure.
-#endif
+				// Returns false if the system doesn't support
+				// blocking/nonblocking modes.
 
 		bool	lingerOnClose(int timeout);
 			// Instructs the socket to stay open for
